from .. import elements as el
from .combo import combo
from .checkbox import checkbox


def dark_mode_toggle(checked=None):
    """
    Provides a toggle for switching between light and dark mode.
    The checkbox uses the theme's current mode by defualt, and thus
    it follows the system's OS setting if "system" is the current
    mode. Once the user clicks the toggle, the mode will override
    to dark or light. Separate logic is required to revert to "system" mode.
    """
    theme = el.theme()
    edited = el.state(value=False)

    if checked is None:
        checked = theme.is_dark

    # TODO: Make this an icon_button
    toggle = checkbox("Dark mode", checked=checked)

    # TODO: Use a checkbox "changed" prop
    # TODO: Provide a way to revert to "system" mode.
    if not edited.value and toggle.checked != theme.is_dark:
        edited.value = True
    if edited.value:
        theme.mode = "dark" if toggle.checked else "light"

    return combo((toggle, ["checked"] + el.input_props))
