from .combo import combo
from .. import elements as el


class dialog(combo):
    """A dialog with an arbitrary body container."""

    def __init__(self, title, buttons=None, **props):
        if buttons is None:
            buttons = ["Cancel", "OK"]

        with el.modal(
            padding=16,
            gap=16,
            border_radius=10,
        ) as self.element:

            el.text(f"### {title}")
            self.content_slot = el.slot()
            self.buttons_container_slot = el.slot()

        for button_label in buttons:
            with el.scope(button_label):
                self.add_button(button_label)

        super().__init__(
            (
                self.element,
                ["opened", "width", "height"] + el.input_props,
            ),
            init=props,
            changed_props=["opened"],
        )

    @property
    def dismissed(self):
        return self.opened_changed and not self.opened

    def content(self, *args, **kwargs):
        with self.content_slot:
            return el.container(*args, **kwargs)

    def add_button(self, *args, **kwargs):
        if self.buttons_container_slot.is_empty:
            with self.buttons_container_slot:
                self.buttons_container = el.container(
                    direction="horizontal",
                    justify="end",
                    gap=8,
                )

        # Add the button to the button container:
        with self.buttons_container:
            button = el.button(*args, **kwargs)

        # Note: It's unclear if all buttons should close the dialog
        # when clicked, but that's the behavior for now.
        if button.clicked:
            self.element.opened = False

        return button

    def get_button(self, label):
        for button in self.buttons_container.children:
            if button.label == label:
                return button
        return None

    @property
    def clicked_button(self):
        for button in self.buttons_container.children:
            if button.clicked:
                return button.label
        return None


class simple_dialog:
    def __init__(self, buttons=["OK"]):
        self.state = el.state(title="", content="", buttons=buttons)
        self.dialog = dialog(self.state.title, buttons=self.state.buttons)
        with self.dialog.content():
            el.text(self.state.content)

    def open(self, title, content, buttons=None):
        if buttons:
            self.state.buttons = buttons
        self.state.title = title
        self.state.content = content
        self.dialog.opened = True

    @property
    def clicked_button(self):
        return self.dialog.clicked_button

    @property
    def dismissed(self):
        return self.dialog.dismissed
