from ..core.element import Prop, parse_option
from .. import elements as el
from .combo import combo


class drawer_element(el.modal):
    name = "modal"
    # Override position to only support left/right
    position = Prop("left", parse=parse_option("left", "right"))


class drawer(combo):
    """A drawer is a modal that opens on the left or right with 100%
    height and customizable width."""

    def __init__(self, **props):
        with drawer_element(
            width=300,
            height="100%",
            padding=8,
            gap=8,
            horizontal_scroll=True,
            vertical_scroll=True,
        ) as self.element:
            self.content_slot = el.slot()
        super().__init__(
            (
                self.element,
                ["position", "width", "opened", "padding", "gap"] + el.input_props,
            ),
            init=props,
        )

    def content(self, *args, **kwargs):
        with self.content_slot:
            return el.container(*args, **kwargs)


class tray_element(el.modal):
    name = "modal"
    # Override position to only support bottom/top
    position = Prop("bottom", parse=parse_option("top", "bottom"))


class tray(combo):
    """A tray is a modal that opens on the top or bottom with 100% width
    and customizable height."""

    def __init__(self, **props):
        with tray_element(
            width="100%",
            height=200,
            padding=8,
            gap=8,
            horizontal_scroll=True,
            vertical_scroll=True,
        ) as self.element:
            self.content_slot = el.slot()
        super().__init__(
            (
                self.element,
                ["position", "height", "opened", "padding", "gap"] + el.input_props,
            ),
            init=props,
        )

    def content(self, *args, **kwargs):
        with self.content_slot:
            return el.container(*args, **kwargs)
