from .combo import combo
from .. import elements as el


def tab(label, selected=False, key=None):
    # Note that we use button here for accessibility
    # Buttons provide keyboard input (tabs + enter)
    # See this example for details:
    # https://www.w3.org/TR/wai-aria-practices-1.1/examples/tabs/tabs-1/tabs.html
    theme = el.theme()
    return el.button(
        label,
        width="100%",
        height="100%",
        role="tab",
        border=(None, None, theme.input_border, None)
        if not selected
        else (theme.input_border, theme.input_border, None, theme.input_border),
        background_color=theme.background_color,
        font_color=theme.font_color,
        font_weight="normal",
        key=key,
    )


def tabs(values, selected=None, **props):
    state = el.state(selected=selected)

    if len(set(values)) != len(values):
        raise ValueError("Duplicate values are not allowed in tabs.")

    with el.container(
        direction="horizontal",
        role="tablist",
    ) as tabs_container:
        for v in values:
            with el.scope(v):
                selected = v == state.selected

                t = tab(v, selected)

                if t.clicked:
                    state.selected = v

    return combo(
        (tabs_container, ["direction", "gap"] + el.input_props),
        state,
        init=props,
    )
