from nose.tools import assert_raises
from ...core.unittests import simple_test
from ..charts import (
    line_chart,
    bar_chart,
    parse_axis,
    parse_tooltip,
    basic_chart,
    scatter_chart,
)


@simple_test
def test_line_chart(ctx):
    lc = line_chart((1, 2, 3), series_names=("corn", "cheese", "dog"))
    assert lc.data == ((1, 2, 3),)
    assert lc.x_axis == "category"
    assert lc.series_names == ("corn", "cheese", "dog")


@simple_test
def test_bar_chart(ctx):
    bc = bar_chart((1, 2, 3), series_names=("corn", "cheese", "dog"))
    assert bc.data == ((1, 2, 3),)


@simple_test
def test_scatter_chart(ctx):
    sc = scatter_chart(((1, 3), (2, 4), (5, 6)))
    assert sc.x_axis == "value"


@simple_test
def test_basic_chart(ctx):
    assert_raises(ValueError, basic_chart, "line")
    assert_raises(ValueError, basic_chart, "cheese", (1, 2, 3), x_axis="category")
    assert_raises(
        ValueError, basic_chart, "scatter", (1, 2, 3), x_axis="value", y_axis="value"
    )

    bc = basic_chart("bar", (1, 2, 3), x_axis="category", rotate=True)
    assert bc.rotate


def test_parse_axis():
    assert parse_axis(None) == dict(show=False)
    assert parse_axis("time") == dict(type="time")
    assert parse_axis((1, 3)) == dict(type="category", data=(1, 3))
    assert_raises(ValueError, parse_axis, "bunnies")


def test_parse_tooltip():
    assert parse_tooltip(None) is None
    assert parse_tooltip("axis") == dict(trigger="axis")
    assert_raises(ValueError, parse_tooltip, "bunnies")
