from ...core.unittests import simple_test
from ... import elements as el
from ..dialog import dialog


@simple_test
def test_dialog(ctx):
    d = dialog("Title", buttons=[])
    assert d.content_slot.is_empty
    assert d.buttons_container_slot.is_empty

    with d.content(width=100, height=100, background_color="#eee"):
        hello_text = el.text("Hello")

    assert not d.content_slot.is_empty

    # Adding and getting buttons
    b = d.add_button("Hello")
    assert b.name == "button"
    assert b.label == "Hello"

    assert not d.buttons_container_slot.is_empty

    assert d.get_button("Hello") == b

    # Assert the shape of the dom tree:
    assert len(d.element.children) == 3

    # First element is the title
    assert d.element.children[0].name == "text"
    assert d.element.children[0].label == "### Title"

    # Second is the content container
    assert d.element.children[1].name == "container"
    assert d.element.children[1].width == 100
    assert d.element.children[1].height == 100
    assert d.element.children[1].background_color == "#eee"
    assert d.element.children[1].children == [hello_text]

    # Third is the buttons container
    assert d.element.children[2].name == "container"
    assert len(d.element.children[2].children) == 1
    assert d.element.children[2].children == [b]


@simple_test
def test_dialog_default_buttons(ctx):
    d = dialog("My Dialog")

    # Cancel, OK buttons by default
    assert not d.buttons_container_slot.is_empty
    b1 = d.get_button("Cancel")
    b2 = d.get_button("OK")
    assert b1 is not None
    assert b2 is not None
    assert d.element.children[2].children == [b1, b2]

    # Nonexistent button
    assert d.get_button("Something") is None

    # Nothing is clicked (TODO: Need to be able to simulate UI events
    # to test clicked behavior)
    assert d.clicked_button is None
