from nose.tools import nottest
import contextlib
from functools import wraps
from .context import Context


@nottest
def simple_test(fn):
    """Decorator for basic unit tests. Sets up a context and root
    collector and cleans up on exit. Example:

    @simple_test
    def test_stuff():
      b = hd.button('Hello')
      assert b.label == 'Hello'

    """

    @wraps(fn)
    def wrapper():
        ctx = Context(lambda x: x)
        Context.set_current_context(ctx)
        ctx.collector_stack.push([])
        try:
            fn(ctx)
        finally:
            Context.clear_current_context()

    return wrapper


@contextlib.contextmanager
def should_raise(msg=None):
    """Helper context manager to run code whose expected condition is to
    raise an error. If the body of the context manager does *not* raise
    an error, should_raise *will* raise an error. Example:

    c = container()
    with should_raise():
      c.direction = 'up'

    """
    try:
        yield
    except Exception:
        return

    assert False, msg
