from .container import container
from .select_ import select
from .checkbox import checkbox
from .text_input import text_input
from .radio import radio

input_types = (
    text_input,
    select,
    radio,
    checkbox,
)


def get_form_inputs(children):
    inputs = []
    for c in children:
        if isinstance(c, input_types):
            inputs.append(c)
        elif c.is_container and not isinstance(c, form):
            inputs.extend(get_form_inputs(c.children))
    return inputs


class form(container):
    is_container = True

    def __init__(self, *args, **kwargs):
        self._inputs = []
        super().__init__(self, *args, **kwargs)

    def __exit__(self, *args):
        super().__exit__(*args)
        self._inputs = get_form_inputs(self.children)

    @property
    def can_submit(self):
        return all([i.valid and not (i.required and i.is_empty) for i in self._inputs])

    def reset(self):
        for i in self._inputs:
            i.reset()
