from ..core.element import Prop
from .styled_element import StyledElement
import os
import hashlib
from urllib.parse import urlparse
from ..core.utils import static_directory


def is_url(src):
    try:
        value = urlparse(src)
        # Require a domain and http(s).
        return value.netloc != "" and value.scheme in ("http", "https")
    except ValueError:
        return False


def persistent_hash(strval, length=8):
    return hashlib.md5(strval.encode()).hexdigest()[:length]


def parse_src(src):
    if src is None or src == "":
        return src

    if is_url(src):
        return src

    src = os.path.abspath(src)
    if not os.path.exists(src):
        raise ValueError("Image does not exist.")

    sourcedir = os.path.dirname(src)
    filename = os.path.basename(src)

    if sourcedir != static_directory:
        sourcedir_hash = persistent_hash(sourcedir)
        filename = f"{sourcedir_hash}_{filename}"

    hosted_path = os.path.join(static_directory, filename)
    # Do not copy the file if it already
    # exists at the destination
    if not os.path.exists(hosted_path):
        os.symlink(src, hosted_path)

    return f"/static/{filename}"


class image(StyledElement):
    src = Prop(parse=parse_src)
    text = Prop("")

    def args_to_props(self, *args, **kwargs):
        if args:
            kwargs["src"] = args[0]
        return kwargs
